@@ -2,7 +2,7 @@ import hashlib
 import cryptography
 from cryptography.fernet import Fernet
 import os.path
-import fire
+
 
 class VeryPy:
   def __init__(self, source_file, hash_file, key):
@@ -118,10 +118,7 @@ class VeryPy:
     self.hasher()
     self.encrypter()
 
-if __name__ == '__main__':
-  fire.Fire(VeryPy(sys.argv[1], sys.argv[2], sys.argv[3]))
 
 
 
-#veripy = VeriPy('test.txt', 'hash.txt', 'key.key')
-verypy = VeryPy(sys.argv[1],sys.argv[2], sys.argv[3])
\ No newline at end of file
+
